@@ -1,5 +1,5 @@
 package OTRS::OPM::Installer;
-$OTRS::OPM::Installer::VERSION = '0.02';
+$OTRS::OPM::Installer::VERSION = '0.03';
 # ABSTRACT: Install OTRS add ons
 
 use v5.10;
@@ -23,14 +23,32 @@ has package      => ( is => 'ro', isa => Str );
 has otrs_version => ( is => 'ro', isa => Str, lazy => 1, default => \&_build_otrs_version );
 has prove        => ( is => 'ro', default => sub { 0 } );
 has manager      => ( is => 'ro', lazy => 1, default => \&_build_manager );
+has repositories => ( is => 'ro', isa => ArrayRef[Str] );
 has conf         => ( is => 'ro' );
 has sudo         => ( is => 'ro' );
 has utils_otrs   => ( is => 'ro', lazy => 1, default => sub{ OTRS::OPM::Installer::Utils::OTRS->new } );
 has verbose      => ( is => 'ro', default => sub { 0 } );
 has logger       => ( is => 'ro', lazy => 1, default => sub { OTRS::OPM::Installer::Logger->new } );
 
+sub list_available {
+    my ( $self, %params ) = @_;
+
+    my %file_opts;
+    if ( $params{repositories} and ref $params{repositories} eq 'ARRAY' ) {
+        $file_opts{repositories} = $params{repositories};
+    }
+
+    my $package_utils = OTRS::OPM::Installer::Utils::File->new(
+        %file_opts,
+        package      => 'DummyPackage',   # ::File needs a package set
+        otrs_version => $self->otrs_version,
+    );
+
+    return $package_utils->list_available;
+}
+
 sub install {
-    my $self   = shift;
+    my $self = shift;
 
     if ( @_ % 2 ) {
         unshift @_, 'package';
@@ -39,6 +57,10 @@ sub install {
     my %params = @_;
 
     my %file_opts;
+    if ( $self->repositories ) {
+        $file_opts{repositories} = $self->repositories;
+    }
+
     if ( $params{repositories} and ref $params{repositories} eq 'ARRAY' ) {
         $file_opts{repositories} = $params{repositories};
     }
@@ -94,7 +116,7 @@ sub install {
 
         $self->logger->debug( message => $message );
         say $message;
-        exit 0;
+        return;
     }
 
     say sprintf "Working on %s...", $parsed->name if $self->verbose;
@@ -137,6 +159,8 @@ sub install {
     $self->logger->debug( message => $message );
 
     $self->manager->PackageInstall( String => $content );
+
+    return 1;
 }
 
 sub _cpan_install {
@@ -205,7 +229,7 @@ OTRS::OPM::Installer - Install OTRS add ons
 
 =head1 VERSION
 
-version 0.02
+version 0.03
 
 =head1 SYNOPSIS
 
@@ -251,8 +275,8 @@ dependencies and it can handle dependencies from different places:
 
 You can provide some basic configuration in a F<.opminstaller.rc> file:
 
-  repository=ftp://ftp.otrs.org/pub/otrs/packages
-  repository=ftp://ftp.otrs.org/pub/otrs/itsm/packages33
+  repository=http://ftp.otrs.org/pub/otrs/packages
+  repository=http://ftp.otrs.org/pub/otrs/itsm/packages33
   repository=http://opar.perl-services.de
   repository=http://feature-addons.de/repo
   otrs_path=/srv/otrs
